"use strict";

utils.setBaseWidth(750);
var dailyWordsCountEchartsInstance;

var getDailyWordsCountOption = function getDailyWordsCountOption() {
  var option = {
    color: ['#2DBCFF'],
    title: {
      text: '每日书籍字数变化统计图',
      textStyle: {
        color: '#2a2a2a',
        fontSize: utils.px(18)
      },
      padding: 0,
      bottom: utils.px(30),
      left: 'center'
    },
    grid: {
      /* top: px(196), */
      left: utils.px(96),
      right: utils.px(0),
      top: utils.px(50),
      bottom: utils.px(120)
      /* bottom: px(150), */

    },
    yAxis: {
      position: 'left',
      offset: utils.px(72),
      axisLabel: {
        align: 'left',
        textStyle: {
          color: '#B0BAC3',
          fontSize: utils.px(16)
        }
      },
      type: 'value',
      axisLine: {
        show: false
      },
      axisTick: {
        /* alignWithLabel: true, */
        show: false
      },
      splitLine: {
        lineStyle: {
          color: '#F8FAFB',
          type: 'dashed'
        }
      }
    },
    xAxis: {
      offset: utils.px(10),
      data: utils.getRandomDate(),
      axisLine: {
        lineStyle: {
          color: '#F0F0F0',
          width: '2'
        }
      },
      boundaryGap: true,
      axisTick: {
        show: false
      },
      axisLabel: {
        formatter: function formatter(data) {
          return utils.formatterDate(new Date(data), 'MM-DD');
        },
        textStyle: {
          color: '#B0BAC3',
          fontSize: utils.px(16)
        }
      }
    },
    tooltip: {
      backgroundColor: '#fff',
      borderColor: '#ECF1F7',
      borderWidth: 1,
      textStyle: {
        color: '#98A2AB'
      },
      padding: [utils.px(10), utils.px(32), utils.px(10), utils.px(16)],
      formatter: function formatter(dataList) {
        var result = utils.formatterDate(new Date(dataList[0].axisValue), 'YYYY年MM月DD日');
        result = "\n          <div\n            style=\"\n            font-size: ".concat(utils.px(18), "px;\n            line-height: ").concat(utils.px(30), "px;\n            \" >\n            ").concat(result, "\n          </div>\n        ");

        for (var i = 0; i < dataList.length; i += 1) {
          result += "\n            <div>\n              <sapn\n                style=\"\n                  margin-right: ".concat(utils.px(10), "px;\n                  display: inline-block;\n                  width: ").concat(utils.px(12), "px;\n                  height: ").concat(utils.px(12), "px;\n                  border-radius: 50%;\n                  background-color: ").concat(dataList[i].color, "\" >\n              </sapn>\n              <span\n                style=\"\n                font-size: ").concat(utils.px(18), "px;\n                line-height: ").concat(utils.px(30), "px;\n                \">\n                \u4E66\u7C4D\u53D8\u5316\u5B57\u6570:\n                ").concat(utils.formatterCountByPrefix(dataList[i].value), "\n              </span>\n            <div>\n          ");
        }

        return result;
      },
      trigger: 'axis',
      axisPointer: {
        lineStyle: {
          width: 0
        }
      }
    },
    series: [{
      name: '书籍总数',
      type: 'bar',
      // barMinHeight: utils.px(10),
      emphasis: {
        itemStyle: {
          color: '#5786FF'
        }
      }
    }]
  };
  /* console.log(option); */

  return option;
};

window.setDailyWordsCountData = function (_data, period) {
  var data = utils.parseJSON(_data);

  if (utils.isNull(data) || utils.isNotObject(data) || utils.isNotDateArray(data.dateList) || utils.isNotNumberArray(data.change) || utils.isNotNumber(data.totalWordsCount) || utils.isNotNumber(data.todayWordsCountChange) || utils.isNotNumber(data.dailyHighestWordsCountChange)) {
    data = {
      totalWordsCount: 0,
      todayWordsCountChange: 0,
      dailyHighestWordsCountChange: 0,
      dateList: utils.getDefaultDate(),
      change: utils.getDefaultNumberData()
    };
  }

  var isDefaultData = utils.isDefaultData(data.change);

  for (var i = 0; i < data.change.length; i += 1) {
    data.change[i] = {
      value: data.change[i],
      itemStyle: {
        color: data.change[i] > 0 ? '#2DBCFF' : '#E0F4FF',
        opacity: data.change[i] ? 1 : 0
      },
      label: {
        show: period === 7 && data.change[i],
        position: data.change[i] > 0 ? 'top' : 'bottom',
        color: data.change[i] > 0 ? '#2DBCFF' : '#89D9FF',
        fontSize: utils.px(18)
      }
    };
  }

  var option = {
    tooltip: {
      show: !isDefaultData
    },
    xAxis: {
      data: data.dateList
    },
    series: [{
      data: data.change
    }]
  };
  /* console.log(option); */

  /* dailyWordsCountEchartsInstance.setOption(option); */

  utils.setOption(dailyWordsCountEchartsInstance, option);
  var totalWordsCount = document.getElementById('total-words-count');
  totalWordsCount.innerText = utils.formatterCount(data.totalWordsCount);
  var todayWordsCountChange = document.getElementById('today-words-count-change');
  todayWordsCountChange.innerText = utils.formatterCountByPrefix(data.todayWordsCountChange);
  var dailyHighestWordsCountChange = document.getElementById('daily-highest-words-count');
  dailyHighestWordsCountChange.innerText = utils.formatterCountByPrefix(data.dailyHighestWordsCountChange);
};

var dailyCodeWordsTimeEchartsInstance;

var getDailyCodeWordsTimeOption = function getDailyCodeWordsTimeOption() {
  var option = {
    color: ['#2DBCFF', '#E8EAEE'],
    legend: {
      bottom: utils.px(20),
      padding: 0,
      itemGap: utils.px(30),
      itemWidth: utils.px(16),
      itemHeight: utils.px(16),
      data: [{
        name: 'App端码字',
        // icon: 'path://m234.5,170.5c0,-8.839779 7.160221,-16 16,-16c8.839779,0 16,7.160221 16,16c0,8.839779 -7.160221,16 -16,16c-8.839779,0 -16,-7.160221 -16,-16z',
        icon: 'roundRect',
        textStyle: {
          color: '#2a2a2a',
          fontSize: utils.px(18)
        }
      }, {
        name: 'PC端码字',
        // icon: 'path://m83.5,146.5c0,-8.839779 6.712707,-16 15,-16c8.287293,0 15,7.160221 15,16c0,8.839779 -6.712707,16 -15,16c-8.287293,0 -15,-7.160221 -15,-16z',
        icon: 'roundRect',
        textStyle: {
          color: '#2a2a2a',
          fontSize: utils.px(18)
        }
      }]
    },
    tooltip: {
      backgroundColor: '#fff',
      borderColor: '#ECF1F7',
      borderWidth: 1,
      textStyle: {
        color: '#98A2AB'
      },
      padding: [utils.px(10), utils.px(32), utils.px(10), utils.px(16)],
      formatter: function formatter(dataList) {
        /* console.log(dataList); */
        var result = utils.formatterDate(new Date(dataList[0].axisValue), 'YYYY年MM月DD日');
        result = "\n          <div\n            style=\"\n              font-size: ".concat(utils.px(18), "px;\n              line-height: ").concat(utils.px(30), "px;\n            \" >\n            ").concat(result, "\n          </div>\n        ");

        for (var i = 0; i < dataList.length; i += 1) {
          result += "\n            <div>\n              <sapn\n                style=\"\n                  margin-right: ".concat(utils.px(10), "px;\n                  display: inline-block;\n                  width: ").concat(utils.px(12), "px;\n                  height: ").concat(utils.px(12), "px;\n                  border-radius: 50%;\n                  background-color: ").concat(dataList[i].color, "\" >\n              </sapn>\n              <span\n                style=\"\n                  font-size: ").concat(utils.px(18), "px;\n                  line-height: ").concat(utils.px(30), "px;\n                \">\n                ").concat(dataList[i].seriesName, "\uFF1A").concat(utils.formatterLocalDate(dataList[i].value), "\n              </span>\n            <div>\n          ");
        }

        return result;
      },
      trigger: 'axis',
      axisPointer: {
        type: 'line',
        lineStyle: {
          width: 0
        }
      }
    },
    grid: {
      /* top: px(196), */
      left: utils.px(20),
      right: utils.px(80),
      top: utils.px(50),
      bottom: utils.px(130)
    },
    xAxis: {
      data: utils.getRandomDate(),
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      },
      axisLabel: {
        formatter: function formatter(data) {
          return utils.formatterDate(new Date(data), 'MM-DD');
        },
        textStyle: {
          color: '#B0BAC3',
          fontSize: utils.px(16)
        }
      }
    },
    yAxis: {
      position: 'right',
      offset: utils.px(60),
      axisLabel: {
        align: 'right',
        color: '#B0BAC3',
        fontSize: utils.px(16),
        formatter: '{value}h'
      },
      type: 'value',
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      },
      splitLine: {
        show: false
      }
    },
    series: [{
      name: 'App端码字',
      type: 'bar',
      data: utils.getDefaultNumberData(),
      stack: true,
      barMaxWidth: utils.px(32),
      barMinHeight: utils.px(10),
      emphasis: {
        itemStyle: {
          color: '#5786FF'
        }
      }
    }, {
      name: 'PC端码字',
      type: 'bar',
      stack: true,
      data: utils.getDefaultNumberData(),
      barMaxWidth: utils.px(32),
      barMinHeight: utils.px(10),
      emphasis: {
        itemStyle: {
          color: '#C7DAFF'
        }
      }
    }]
  };
  return option;
};

window.setDailyCodeWordsTimeData = function (_data, period) {
  var data = utils.parseJSON(_data);
  /* console.log(data); */

  if (utils.isNotObject(data) || utils.isNotDateArray(data.dateList) || utils.isNotNumberArray(data.app) || utils.isNotNumberArray(data.pc) || utils.isNotNumber(data.totalCodeWordsTime) || utils.isNotNumber(data.appCodeWordsTime) || utils.isNotNumber(data.appTodayCodeWordsTime)) {
    data = {
      totalCodeWordsTime: 0,
      appCodeWordsTime: 0,
      appTodayCodeWordsTime: 0,
      dateList: utils.getDefaultDate(),
      pc: utils.getDefaultNumberData(),
      app: utils.getDefaultNumberData()
    };
  }

  var option = {
    xAxis: {
      data: data.dateList
    },
    tooltip: {
      show: !utils.isDefaultData(data.app, data.pc)
    },
    series: [{
      data: utils.getBarData(data.app, data.pc, 'down', period)
    }, {
      data: utils.getBarData(data.pc, data.app, 'up', period)
    }]
  };
  /* dailyCodeWordsTimeEchartsInstance.setOption(option); */

  utils.setOption(dailyCodeWordsTimeEchartsInstance, option);
  var totalCodeWordsTime = document.getElementById('total-code-words-time');
  totalCodeWordsTime.innerText = utils.formatterLocalDate(data.totalCodeWordsTime);
  var appCodeWordsTime = document.getElementById('app-code-words-time');
  appCodeWordsTime.innerText = utils.formatterLocalDate(data.appCodeWordsTime);
  var appTodayCodeWordsTime = document.getElementById('app-today-code-words-time');
  appTodayCodeWordsTime.innerText = utils.formatterLocalDate(data.appTodayCodeWordsTime);
};

window.getBookDailyWordsCountDataTest = function (period) {
  var data = {
    totalWordsCount: utils.getRandomNumber(),
    todayWordsCountChange: utils.getRandomNumber(),
    dailyHighestWordsCountChange: utils.getRandomNumber(),

    /* dateList: [], */
    dateList: utils.getDefaultDateData(period),
    total: [],
    change: []
  };

  for (var i = 0; i < period; i += 1) {
    /* data.dateList.push(new Date(2018, utils.random(0, 12), utils.random(0, 30))); */
    data.total.push(utils.getRandomNumber());
    data.change.push(utils.getRandomNumber());
  }
  /* return JSON.stringify(data); */


  window.setDailyWordsCountData(JSON.stringify(data), period);
};
/*
 * window.app = {
 *   getBookDailyWordsCountData: window.getBookDailyWordsCountDataTest,
 * }
 */


window.getBookDailyCodeWordsTimeDataTest = function (period) {
  var data = {
    totalCodeWordsTime: utils.getRandomNumber(),
    appCodeWordsTime: utils.getRandomNumber(),
    appTodayCodeWordsTime: utils.getRandomNumber(),

    /* dateList: [], */
    dateList: utils.getDefaultDateData(period),
    app: [],
    pc: []
  };
  /* console.log(data); */

  for (var i = 0; i < period; i += 1) {
    /* data.dateList.push(new Date(2018, utils.random(0, 12), utils.random(0, 30))); */
    data.app.push(utils.getRandomNumber());
    data.pc.push(utils.getRandomNumber());
  }
  /* return JSON.stringify(data); */


  window.setDailyCodeWordsTimeData(JSON.stringify(data), period);
};

var init = function init() {
  /* 初始化码字字数图表 */
  var dailyWordsCountDom = document.getElementById('daily-words-count');
  dailyWordsCountEchartsInstance = echarts.init(dailyWordsCountDom);
  var dailyWordsCountOption = getDailyWordsCountOption();
  /* dailyWordsCountEchartsInstance.setOption(dailyWordsCountOption); */

  utils.setOption(dailyWordsCountEchartsInstance, dailyWordsCountOption);
  /* 初始化码字时长图表 */

  var dailyCodeWordsTimeDom = document.getElementById('daily-code-words-time');
  dailyCodeWordsTimeEchartsInstance = echarts.init(dailyCodeWordsTimeDom);
  var dailyCodeWordsTimeOption = getDailyCodeWordsTimeOption();
  /* dailyCodeWordsTimeEchartsInstance.setOption(dailyCodeWordsTimeOption); */

  utils.setOption(dailyCodeWordsTimeEchartsInstance, dailyCodeWordsTimeOption);
  /*
   * 获取宿主接口函数
   * ios函数挂载window
   * andorid约定挂载window.app
   * 如果都拿不到就获取测试数据
   * 并获取默认一周数据
   */

  utils.call('getBookDailyWordsCountData', 7);
  utils.call('getBookDailyCodeWordsTimeData', 7);
  var dailyWordsCountWeek = document.getElementById('daily-words-count-week');
  var dailyWordsCountMonth = document.getElementById('daily-words-count-month');

  dailyWordsCountWeek.onclick = function () {
    /* 如果当前是激活状态就不重新获取数据 */
    if (dailyWordsCountWeek.style.color === 'rgb(45, 188, 255)') {
      return;
    }
    /* 切换颜色 */


    dailyWordsCountWeek.style.color = '#2DBCFF';
    dailyWordsCountMonth.style.color = '#C0CBD4';
    /* 获取周数据 */

    /* const bookDailyWordsCountData = getBookDailyWordsCountData(7); */

    utils.call('getBookDailyWordsCountData', 7);
    /* setDailyWordsCountData(bookDailyWordsCountData); */
  };

  dailyWordsCountMonth.onclick = function () {
    /* 如果当前是激活状态就不重新获取数据 */
    if (dailyWordsCountMonth.style.color === 'rgb(45, 188, 255)') {
      return;
    }
    /* 切换颜色 */


    dailyWordsCountWeek.style.color = '#C0CBD4';
    dailyWordsCountMonth.style.color = '#2DBCFF';
    /* 获取月数据 */

    /* const bookDailyWordsCountData = getBookDailyWordsCountData(30); */

    utils.call('getBookDailyWordsCountData', 30);
    /* setDailyWordsCountData(bookDailyWordsCountData); */
  };

  var dailyCodeWordsTimeWeek = document.getElementById('daily-code-words-time-week');
  var dailyCodeWordsTimeMonth = document.getElementById('daily-code-words-time-month');

  dailyCodeWordsTimeWeek.onclick = function () {
    /* 如果当前是激活状态就不重新获取数据 */
    if (dailyCodeWordsTimeWeek.style.color === 'rgb(45, 188, 255)') {
      return;
    }
    /* 切换颜色 */


    dailyCodeWordsTimeWeek.style.color = '#2DBCFF';
    dailyCodeWordsTimeMonth.style.color = '#C0CBD4';
    /* 获取周数据 */

    /* const bookDailyCodeWordsTimeData = getBookDailyCodeWordsTimeData(7); */

    utils.call('getBookDailyCodeWordsTimeData', 7);
    /* setDailyCodeWordsTimeData(bookDailyCodeWordsTimeData); */
  };

  dailyCodeWordsTimeMonth.onclick = function () {
    /* 如果当前是激活状态就不重新获取数据 */
    if (dailyCodeWordsTimeMonth.style.color === 'rgb(45, 188, 255)') {
      return;
    }
    /* 切换颜色 */


    dailyCodeWordsTimeMonth.style.color = '#2DBCFF';
    dailyCodeWordsTimeWeek.style.color = '#C0CBD4';
    /* 获取月数据 */

    /* const bookDailyCodeWordsTimeData = getBookDailyCodeWordsTimeData(30); */

    utils.call('getBookDailyCodeWordsTimeData', 30);
    /* setDailyCodeWordsTimeData(bookDailyCodeWordsTimeData); */
  };
};

if (utils.isAndroid()) {
  window.init = init;
} else {
  window.onload = init;
}