"use strict";

var setBaseWidth = function setBaseWidth() {
  var width = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 750;
  var docEl = document.documentElement;
  var resizeEvt = 'orientationchange' in window ? 'orientationchange' : 'resize';

  var recalc = function recalc() {
    var clientWidth = document.documentElement.clientWidth;
    docEl.style.fontSize = "".concat((100 * (clientWidth / width)).toFixed(2), "px");
  };

  if (document.addEventListener) {
    window.addEventListener(resizeEvt, recalc, false);
    document.addEventListener('DOMContentLoaded', recalc, false);
  }
};

var random = function random(min, max) {
  var range = max - min;
  var rand = Math.random();
  var num = min + Math.round(rand * range);
  return num;
}; // const getRandomNumber = (start = 0, stop = 1000) => Number(Math.round(Math.random()) ? `-${random(start, stop)}` : random(start, stop))
// const getRandomNumber = (start = 0, stop = 100) => random(start, stop)
// const getRandomNumber = (start = 0, stop = 100) => Number(`${random(start, stop)}.${Math.floor(Math.random() * 10)}${Math.floor(Math.random() * 10)}`);
// const getRandomNumber = () => random(0, 0);


var getRandomNumber = function getRandomNumber() {
  return random(0, 1000);
};

var getType = function getType(data) {
  var type = Object.prototype.toString.call(data);
  type = type.slice(8, -1);
  return type;
};

var isNull = function isNull(data) {
  var type = getType(data);
  if (type === 'Null') return true;
  return false;
};

var isString = function isString(data) {
  var type = getType(data);
  if (type === 'String') return true;
  return false;
};

var isNotString = function isNotString(data) {
  return !isString(data);
};

var isNotStringOrEmpty = function isNotStringOrEmpty(data) {
  if (isNotString(data)) return true;
  if (data === '') return true;
  return false;
};

var isNumber = function isNumber(data) {
  var type = getType(data);
  if (type === 'Number') return true;
  return false;
};

var isNotNumber = function isNotNumber(data) {
  return !isNumber(data);
};

var isDate = function isDate(data) {
  var type = getType(data);
  if (type === 'Date') return true;
  return false;
};

var isNotDate = function isNotDate(data) {
  return !isDate(data);
};

var parseJSON = function parseJSON(data) {
  if (isNotStringOrEmpty(data)) return null;

  try {
    var json = JSON.parse(data, function (key, value) {
      if (isNumber(value)) {
        if (String(value).length === 13) {
          if (new Date(value).getFullYear() !== 1970) return new Date(value);
        } else if (String(value).indexOf('.') !== -1) {
          /* console.log(value); */
          if (Math.floor(Number(value * 1000))) return Number(Number(value).toFixed(3));
          return 0.001;
        }

        return value;
      }

      return value;
    });
    return json;
  } catch (e) {
    return null;
  }
};

var isArray = function isArray(data) {
  var type = getType(data);
  if (type === 'Array') return true;
  return false;
};

var isNotArray = function isNotArray(data) {
  return !isArray(data);
};

var isDateArray = function isDateArray(array) {
  if (isNotArray(array)) return false;

  for (var i = 0; i < array.length; i += 1) {
    if (isNotDate(array[i])) return false;
  }

  return true;
};

var isNotDateArray = function isNotDateArray(array) {
  return !isDateArray(array);
};

var isObject = function isObject(data) {
  var type = getType(data);
  if (type === 'Object') return true;
  return false;
};

var isNotObject = function isNotObject(data) {
  return !isObject(data);
};

var isNumberArray = function isNumberArray(array) {
  if (isNotArray(array)) return false;

  for (var i = 0; i < array.length; i += 1) {
    if (isNotNumber(array[i])) return false;
  }

  return true;
};

var isNotNumberArray = function isNotNumberArray(array) {
  return !isNumberArray(array);
};

var addPrefixZero = function addPrefixZero(string) {
  if (Number(string) < 10) return "0".concat(string);
  return string;
};

var formatterLocalDate = function formatterLocalDate(_hour) {
  // 保证最小时1分钟 0.0167 = 1 / 60;
  var hour = _hour ? Math.max(_hour, 0.017) : 0;
  return "".concat(Math.floor(hour), "\u65F6").concat(Math.floor((hour - Math.floor(hour)) * 60), "\u5206");
};

var formatterNumber = function formatterNumber(number) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Number.MAX_VALUE;
  var min = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Number.MIN_VALUE;
  var precision = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
  if (isNaN(number)) return 0;
  if (isNaN(max)) max = Number.MAX_VALUE;
  if (isNaN(min)) min = Number.MIN_VALUE;
  if (isNaN(precision)) precision = 1;
  if (number > max) return max;
  if (number === 0) return 0;
  if (number < min) return min;
  return Number(number.toFixed(precision));
};

var formatterDate = function formatterDate(date, format) {
  var zero = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  if (isNotDate(date)) return '无效日期';
  if (isNotString(format)) return '无效格式化字符串';
  var formatResult = format;

  if (formatResult.indexOf('YYYY') !== -1) {
    var year = date.getFullYear().toString();
    if (zero) year = addPrefixZero(year);
    formatResult = formatResult.replace('YYYY', year);
  }

  if (formatResult.indexOf('MM') !== -1) {
    var month = (date.getMonth() + 1).toString();
    if (zero) month = addPrefixZero(month);
    formatResult = formatResult.replace('MM', month);
  }

  if (formatResult.indexOf('DD') !== -1) {
    var day = date.getDate().toString();
    if (zero) day = addPrefixZero(day);
    formatResult = formatResult.replace('DD', day);
  }
  /*
   * index = formatResult.indexOf('HH');
   * if (index !== -1) {
   *   let hour = date.getHours().toString();
   *   if (zero) {
   *     hour = addPrefixZero(hour);
   *   }
   *   formatResult = formatResult.replace('HH', hour);
   * }
   */

  /*
   * index = formatResult.indexOf('mm');
   * if (index !== -1) {
   *   const string = addPrefixZero(date.getMinutes().toString());
   *   formatResult = formatResult.replace('mm', string);
   * }
   */

  /*
   * index = formatResult.indexOf('ss');
   * if (index !== -1) {
   *   const string = addPrefixZero(date.getSeconds().toString());
   *   formatResult = formatResult.replace('ss', string);
   * }
   */


  return formatResult;
};

var formatterCount = function formatterCount(count) {
  if (isNotNumber(count)) return 0;
  return Math.max(0, Math.floor(count));
  /* count = Math.floor(count); */

  /* if (count < 10000) {
    return count;
  } */

  /* if (
    count >= 1000
    && count < 10000
  ) {
    return `${parseFloat((count / 1000).toFixed(2))}k`;
  }
   if (
    count >= 10000
    && count < 1000000
  ) {
    return `${parseFloat((count / 10000).toFixed(1))}w`;
  }
   if (
    count >= 1000000
    && count < 100000000
  ) {
    return `${parseFloat((count / 10000).toFixed(2))}w`;
  }
   return 'rich'; */
};

var formatterCountByPrefix = function formatterCountByPrefix(number) {
  if (isNotNumber(number)) return number;
  number = Math.floor(number);
  if (number > 0) return "+".concat(number);
  return number;
};

var px = function px(_number) {
  var number = parseFloat(document.documentElement.style.fontSize) * _number / 100;
  return number;
};

var getRandomDate = function getRandomDate() {
  var period = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 7;
  var dateList = [];

  for (var i = 0; i < period; i += 1) {
    dateList.push(new Date(new Date() - 24 * 3600 * 1000 * (period - i)));
  }

  return dateList;
};

var getDefaultNumberData = function getDefaultNumberData() {
  var _period = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 7;

  var period;
  if (isNotNumber(_period)) period = 7;
  var result = [];

  for (var i = 0; i < period; i += 1) {
    result.push(0);
  }

  return result;
};

var getDefaultDateData = function getDefaultDateData() {
  var period = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 7;
  var dateList = [];

  for (var i = 0; i < period; i += 1) {
    dateList.push(new Date(new Date() - 24 * 3600 * 1000 * (period - i)).getTime());
  }

  return dateList;
};

var getDefaultDate = function getDefaultDate() {
  var period = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 7;
  var dateList = [];

  for (var i = 0; i < period; i += 1) {
    dateList.push(new Date(new Date() - 24 * 3600 * 1000 * (period - i)));
  }

  return dateList;
};

var formatterSpeed = function formatterSpeed(number) {
  var unit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'minute';

  if (isNotNumber(number)) {
    return 0;
  }

  return "".concat(number).concat(unit === 'minute' ? '字/分' : '字/时');
};

var isDefaultData = function isDefaultData() {
  for (var _len = arguments.length, arrayList = new Array(_len), _key = 0; _key < _len; _key++) {
    arrayList[_key] = arguments[_key];
  }

  for (var i = 0; i < arrayList.length; i += 1) {
    if (isArray(arrayList[i])) {
      for (var j = 0; j < arrayList[i].length; j += 1) {
        if (arrayList[i][j] !== 0) return false;
      }
    }
  }

  return true;
};

var getBarData = function getBarData(array1, array2, flag, period) {
  if (isNotNumberArray(array1) || isNotNumberArray(array2) || ['up', 'down'].indexOf(flag) === -1 || array1.length !== array2.length) {
    return array1;
  }

  var result = [];

  var _loop = function _loop(i) {
    var res = {
      value: array1[i],
      itemStyle: {
        opacity: isDefaultData(array1, array2) || !array1[i] ? 0 : 1
      },
      label: {
        formatter: function formatter() {
          return formatterNumber(array1[i] + array2[i], 999999, 0.1, 1);
        },
        show: period === 7,
        fontSize: utils.px(12),
        position: 'top',
        color: '#2DBCFF'
      }
    };
    var radius = utils.px(4);
    if (!array1[i]) res.label.show = false;

    if (!array1[i] || !array2[i]) {
      res.itemStyle.barBorderRadius = new Array(4).fill(radius);
    } else if (flag === 'up') {
      res.itemStyle.barBorderRadius = [radius, radius, 0, 0];
    } else if (flag === 'down') {
      res.itemStyle.barBorderRadius = [0, 0, radius, radius];
      res.label.show = false;
    } else {
      res.itemStyle.barBorderRadius = new Array(4).fill(radius);
    }

    result.push(res);
  };

  for (var i = 0; i < array1.length; i += 1) {
    _loop(i);
  }

  return result;
};

var isAndroid = function isAndroid() {
  var u = window.navigator.userAgent;
  var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Linux') > -1;
  return isAndroid;
};

var isIOS = function isIOS() {
  var u = window.navigator.userAgent;
  var isIOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
  return isIOS;
};

var isMobile = function isMobile() {
  var result = window.navigator.userAgent.match(/(phone|pad|pod|iPhone|iPod|ios|iPad|Android|Mobile|BlackBerry|IEMobile|MQQBrowser|JUC|Fennec|wOSBrowser|BrowserNG|WebOS|Symbian|Windows Phone)/i);
  return !!result;
};

var isPC = function isPC() {
  return !isMobile();
};

var call = function call(funcName) {
  if (utils.isNotString(funcName)) return;

  for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    args[_key2 - 1] = arguments[_key2];
  }

  if (isAndroid()) {
    var _window$app;

    (_window$app = window.app)[funcName].apply(_window$app, args);
  } else if (window[funcName]) {
    var _window;

    (_window = window)[funcName].apply(_window, args);
  } else {
    var _window2;

    (_window2 = window)["".concat(funcName, "Test")].apply(_window2, args);
  }
};

var setOption = function setOption(instance, _option) {
  var option = _option;
  instance.setOption(option);
};

window.utils = {
  isNull: isNull,
  parseJSON: parseJSON,
  random: random,
  isNotDateArray: isNotDateArray,
  isNotObject: isNotObject,
  isNotNumberArray: isNotNumberArray,
  formatterDate: formatterDate,
  formatterNumber: formatterNumber,
  formatterCountByPrefix: formatterCountByPrefix,
  px: px,
  isString: isString,
  isNotString: isNotString,
  isNotStringOrEmpty: isNotStringOrEmpty,
  isNumber: isNumber,
  isNotNumber: isNotNumber,
  isDate: isDate,
  isNotDate: isNotDate,
  isArray: isArray,
  isNotArray: isNotArray,
  isDateArray: isDateArray,
  isObject: isObject,
  isNumberArray: isNumberArray,
  addPrefixZero: addPrefixZero,
  formatterCount: formatterCount,
  getRandomDate: getRandomDate,
  getRandomNumber: getRandomNumber,
  setBaseWidth: setBaseWidth,
  formatterSpeed: formatterSpeed,
  getBarData: getBarData,
  isDefaultData: isDefaultData,
  getDefaultNumberData: getDefaultNumberData,
  getDefaultDateData: getDefaultDateData,
  getDefaultDate: getDefaultDate,
  call: call,
  isAndroid: isAndroid,
  isIOS: isIOS,
  isPC: isPC,
  isMobile: isMobile,
  setOption: setOption,
  formatterLocalDate: formatterLocalDate
};